@@ -169,12 +169,16 @@ rabbit_opts = [
                default=2,
                help='How often times during the heartbeat_timeout_threshold '
                'we check the heartbeat.'),
-    cfg.IntOpt('direct_mandatory_flag',
-               default=True,
-               help='Enable/Disable the RabbitMQ mandatory flag '
-               'for direct send. The direct send is used as reply, '
-               'so the MessageUndeliverable exception is raised '
-               'in case the client queue does not exist.'),
+    cfg.BoolOpt('direct_mandatory_flag',
+                default=True,
+                deprecated_for_removal=True,
+                deprecated_reason='Mandatory flag no longer deactivable.',
+                help='(DEPRECATED) Enable/Disable the RabbitMQ mandatory '
+                'flag for direct send. The direct send is used as reply, '
+                'so the MessageUndeliverable exception is raised '
+                'in case the client queue does not exist.'
+                'This flag is deprecated and it will not be possible to '
+                'deactivate this functionality anymore'),
     cfg.BoolOpt('enable_cancel_on_failover',
                 default=False,
                 help="Enable x-cancel-on-ha-failover flag so that "
@@ -1261,11 +1265,11 @@ class Connection(object):
 
         _set_current_channel is responsible to cleanup the cache.
         """
-        queue_indentifier = (exchange.name, routing_key)
+        queue_identifier = (exchange.name, routing_key)
         # NOTE(sileht): We only do it once per reconnection
         # the Connection._set_current_channel() is responsible to clear
         # this cache
-        if queue_indentifier not in self._declared_queues:
+        if queue_identifier not in self._declared_queues:
             queue = kombu.entity.Queue(
                 channel=self.channel,
                 exchange=exchange,
@@ -1279,7 +1283,7 @@ class Connection(object):
                 'Connection._publish_and_creates_default_queue: '
                 'declare queue %(key)s on %(exchange)s exchange', log_info)
             queue.declare()
-            self._declared_queues.add(queue_indentifier)
+            self._declared_queues.add(queue_identifier)
 
         self._publish(exchange, msg, routing_key=routing_key, timeout=timeout)
 
